currency

package module
v0.0.0-...-1a72e09 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Jun 2, 2024 License: MIT Imports: 4 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

func AddFormatCurrencyFilter

func AddFormatCurrencyFilter(locale string) factory.AppendFilterFn

AddFormatCurrencyFilter adds a format_currency filter to the filters map. this filter doesn't have full support for all the options of the PHP version. The locale is used to determine the currency symbol and format. The currency code is used to determine the currency symbol. The currency code is optional and defaults to EUR. The value can be a string, int, int32, int64, or big.Int.

func NewCurrencyFormatter

func NewCurrencyFormatter(locale string) *currency.Formatter

Types

This section is empty.

Jump to